@@ -22,7 +22,9 @@ Auth = namedtuple("Auth", [
     "create_user",
     "update_user_email",
     "update_user_metadata",
-    "create_magic_link", "migrate_user_from_external_source", "create_org", "add_user_to_org"
+    "create_magic_link", "migrate_user_from_external_source", "create_org", "add_user_to_org",
+    "delete_user", "disable_user", "enable_user",
+    "allow_org_to_setup_saml_connection", "disallow_org_to_setup_saml_connection"
 ])
 
 
@@ -52,4 +54,9 @@ def init_auth(auth_url: str, api_key: str, token_verification_metadata: TokenVer
         migrate_user_from_external_source=auth.migrate_user_from_external_source,
         create_org=auth.create_org,
         add_user_to_org=auth.add_user_to_org,
+        enable_user=auth.enable_user,
+        disable_user=auth.disable_user,
+        delete_user=auth.delete_user,
+        allow_org_to_setup_saml_connection=auth.allow_org_to_setup_saml_connection,
+        disallow_org_to_setup_saml_connection=auth.disallow_org_to_setup_saml_connection,
     )
